"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * model控制器和页面生成的基本类
 * 2019-09-10 14:47.
 *
 * @author WheelerLee https://github.com/WheelerLee
 * @copyright 2019
 */
const fs_extra_1 = __importDefault(require("fs-extra"));
const ejs_1 = __importDefault(require("ejs"));
class Worker {
    /**
     * 生成控制器
     * @param folderName 文件夹名
     * @param modelName 模型名
     * @param model 模型
     * @param primaryKey 主键
     */
    static generateController(folderName, modelName, model, primaryKey) {
        return __awaiter(this, void 0, void 0, function* () {
            let str = yield fs_extra_1.default.readFile(__dirname + '/../templates/Controller.ejs'); //读取控制器模板
            let controllerStr = ejs_1.default.render(str.toString(), {
                folderName: folderName,
                modelName: modelName,
                model: model,
                primaryKey: primaryKey
            });
            let path = process.cwd() + '/api/controllers/' + folderName + '/';
            yield fs_extra_1.default.ensureDir(path);
            yield fs_extra_1.default.writeFile(path + modelName + 'Controller.js', Buffer.from(controllerStr), { flag: 'w', encoding: 'utf8' });
            // console.log(colors.info('创建 ' + path + modelName + 'Controller.js'));
            return true;
        });
    }
    /**
     * 生成数据页面
     * @param folderName 文件夹名
     * @param modelName  模型名
     * @param model      模型
     * @param primaryKey 主键
     */
    static generateIndexPage(folderName, modelName, model, primaryKey) {
        return __awaiter(this, void 0, void 0, function* () {
            let str = yield fs_extra_1.default.readFile(__dirname + '/../templates/index.ejs'); //读取控制器模板
            let controllerStr = ejs_1.default.render(str.toString(), {
                folderName: folderName,
                modelName: modelName,
                model: model,
                primaryKey: primaryKey
            });
            let path = process.cwd() + '/views/' + folderName + '/' + modelName.toLowerCase() + '/';
            yield fs_extra_1.default.ensureDir(path);
            yield fs_extra_1.default.writeFile(path + 'index.ejs', Buffer.from(controllerStr), { flag: 'w', encoding: 'utf8' });
            // console.log(colors.info('创建 ' + path + 'index.ejs'));
            return true;
        });
    }
    /**
     * 生成添加页面
     * @param folderName 文件夹名
     * @param modelName  模型名
     * @param model      模型
     * @param primaryKey 主键
     */
    static generateAddPage(folderName, modelName, model, primaryKey) {
        return __awaiter(this, void 0, void 0, function* () {
            let str = yield fs_extra_1.default.readFile(__dirname + '/../templates/modify.ejs'); //读取控制器模板
            let controllerStr = ejs_1.default.render(str.toString(), {
                folderName: folderName,
                modelName: modelName,
                model: model,
                primaryKey: primaryKey
            });
            let path = process.cwd() + '/views/' + folderName + '/' + modelName.toLowerCase() + '/';
            yield fs_extra_1.default.ensureDir(path);
            yield fs_extra_1.default.writeFile(path + 'modify.ejs', Buffer.from(controllerStr), { flag: 'w', encoding: 'utf8' });
            // console.log(colors.info('创建 ' + path + 'modify.ejs'));
            return true;
        });
    }
}
exports.default = Worker;
