#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = __importDefault(require("fs-extra"));
const colors_1 = __importDefault(require("colors"));
const commander_1 = __importDefault(require("commander"));
const Generator_1 = __importDefault(require("./Generator"));
const FeatureUtils_1 = __importDefault(require("./FeatureUtils"));
//设置控制台接收UTF8的字符
process.stdin.setEncoding('utf8');
//设置控制台输出的颜色
colors_1.default.setTheme({
    info: ['black', 'bold'],
    question: ['black', 'underline', 'italic'],
    warn: ['yellow', 'bold'],
    error: ['red', 'bold'],
    success: ['green', 'bold'],
    progress: ['blue']
});
commander_1.default.version('6.0.1', '-v, --version', '输出当前的版本号')
    .helpOption('-h, --help', '帮助信息')
    .option('-f, --folder <folder>', '指定生成的文件夹，默认是admin，当然现在也只支持admin。别的文件夹会有路径上的bug')
    .option('-m, --model <model>', '指定生成的model，不指定默认会生成所有的model以及修改config等，指定model将会只生成该model的增删改查')
    .option('--feature <feature>', '添加功能模块')
    .option('--fc', '查询已经集成的功能模块')
    .option('--reset', '重置生成的管理系统，会将和admin相关的都会删除，请谨慎')
    .option('--skip', '忽略依赖添加');
commander_1.default.parse(process.argv);
let feature = commander_1.default.feature;
if (feature && commander_1.default.folder) {
    console.log(colors_1.default.error('生成代码和添加功能模块不能同时执行'));
    process.exit();
}
let folder = 'admin';
if (commander_1.default.folder) {
    folder = commander_1.default.folder;
}
let fc = commander_1.default.fc;
let reset = commander_1.default.reset;
let skip = commander_1.default.skip;
if (fc) { //查询模块
    //第一步先将所有的模块注册到系统中
    FeatureUtils_1.default.autoLink();
    FeatureUtils_1.default.printFeatures();
    process.exit();
}
if (!fs_extra_1.default.existsSync(process.cwd() + '/views/') || !fs_extra_1.default.existsSync(process.cwd() + '/api/')
    || !fs_extra_1.default.existsSync(process.cwd() + '/api/controllers/') || !fs_extra_1.default.existsSync(process.cwd() + '/api/models/')
    || !fs_extra_1.default.existsSync(process.cwd() + '/assets/') || !fs_extra_1.default.existsSync(process.cwd() + '/config/')) {
    console.log(colors_1.default.error('请在项目根目录下运行'));
    process.exit();
}
if (feature) { //添加模块
    //第一步先将所有的模块注册到系统中
    FeatureUtils_1.default.autoLink();
    FeatureUtils_1.default.addFeature(feature);
}
else {
    let generator = new Generator_1.default(folder);
    generator.generate(reset, skip, commander_1.default.model);
}
// console.log('代码生成成功，运行后请访问 http://127.0.0.1:1337/mock/add 添加基础数据');
